{                         PROGRAMMING TOOLS FOR RITZ MODEL                    }


  Const
    MinReal    = -1.0e+208;
    MaxExp     =  350.0;

    DEG_PZ   = 'A';
    DEG_BOTH = 'B';
    DEG_TZ   = 'C';
    VOL_PZ   = 'D';
    VOL_TZ   = 'E';
    LEACH    = 'F';

  Var                         { ----------- INPUT PARAMETERS ---------------- }
    ClappHornberger,          { Clapp & Hornberger constant                   }
    ConcOil,                  { Concentration of oil in applied sludge        }
    ConcPol,                  { Concentration of pollutant in sludge          }
    DensityOil,               { Density of oil in sludge                      }
    DiffCoefWater,            { Diffusion coefficient of water vapor          }
    EvapRate,                 { Evaporation rate                              }
    HalfLifeOil,              { Half-life of oil                              }
    HalfLifePol,              { Half-life of pollutant                        }
    RechargeRate,             { Recharge rate                                 }
    SatWaterContent,          { Saturated water content on volume basis       }
    SatConductivity,          { Saturated hydraulic conductivity              }
    SludgeApplRate,           { Sludge application rate                       }
    PlowZoneDepth,            { Plow zone depth                               }
    TreatZoneDepth,           { Treatment zone depth                          }
    VaporDiffCoefAir,         { Vapor diffusion coefficient in air            }
    bd,                       { Bulk density                                  }
    foc,                      { fraction organic carbon in soil               }
    kh,                       { Vapor:water partition coefficient             }
    koc,                      { Organic carbon partition coefficient          }
    kow,                      { Octanol:water partition coefficient           }
    rh,                       { Relative humidity                             }
    temp,                     { Temperature (deg C)                           }



                              { -----------CALCULATED PARAMETERS ------------ }
    AqueousVelocity,          { Pore water velocity                           }
    DegConstOil,              { Degradation constant for oil                  }
    DegConstPol,              { Degradation constant for pollutant            }
    DensityRatio,             { Ratio of density of water vapor to liquid     }
    DiffCoefSoil,             { Diffusion coefficient of pollutant in soil    }
    InitialAirContent,        { Initial air content (volume fraction)         }
    InitialConcPol,           { Initial concentration of pollutant            }
    InitialOilContent,        { Initial oil content (volume fraction)         }
    MaxDepthSlug,             { Maximum depth of penetration of pollutant     }
    PollutantLoad,            { Mass of pollutant applied per unit area       }
    StagnantLayerThickness,   { Stagnant boundary layer thickness             }
    TimeToPZ,                 { Time top of pollutant reaches plow zone depth }
    TimeToClearTZ,            { Time top of pollutant reaches treatment zone
                                depth                                         }
    TimeToTZ,                 { Time bottom of pollutant reaches treatment 
                                zone depth                                    }
    WaterContent,             { Soil water content (volume fraction)          }
    a,                        { Computational parameter                       }
    g,                        { Computational parameter                       }
    kd,                       { Soil:water partition coefficient              }
    r,                        { Retardation factor for pollutant in treat zone}
    rt,                       { Contribution of oil to retardation            }
    vp              : real;   { Velocity of pollutant in lower treatment zone }



Function Power(y, x : real):real; 
                                  { A.Returns the following if y > 0:
                                      1. Value of y raised to the power x if
                                         absolute value of (x*ln(y)) < 
                                                  Maximum exponent (350 in RITZ)
                                      2. Zero if (x*ln(y)) < - Max. Exponent
                                      3. MinReal if (x*ln(y) > Max. Exponent
                                    B.Returns MinReal (-1.0e+208) if y < 0.
                                    C.Returns 0 if y = 0.

                                    External constants used:
                                      MaxExp = 350.0
                                      MinReal = -1.0E+208

                                    External variables used: None
                                    }

  Var
    p : real;

  Begin         { Power }
    If y > 0 then
      Begin
        p := x*ln(y);
        If Abs(p) < MaxExp then p := exp(p)
        Else if p < 0 then p := 0.0
        Else p := MinReal;
      End
    Else if y < 0 then p := MinReal
    Else p := 0;
    If p > MinReal then Power := p
    Else
      Power := MinReal;
  End;          { Power }




Function Log(value : real ) : real;
                                   { Returns natural logarithm of value,
                                                        ln(value) if value > 0.
                                     Returns MinReal (-1.0e+208) if not.

                                     External constants used:
                                       MinReal = -1.0E+208

                                     External variables used: None
                                     }

  Begin     { Log }
    If value <= 0.0 then Log := MinReal
    Else Log := ln(value);
  End;      { Log }




Function TotalPollutantConc(x, t, SlugTop, SlugBottom : real) : real;

                                  { Returns the total pollutant conc. (sum of 
                                    all phases) at depth x and time t. SlugTop
                                    and SlugBottom are the depths of the top
                                    and bottom of the slug, respectively at
                                    time t.

                                    External constants used : 
                                      MaxExp = 350.
                                    External variables used:
                                      InitialConcPol
                                      DegConstPol   
                                      DegConstOil   
                                      r             
                                      rt            
                                      vp            
                                      PlowZoneDepth
                                    }

  Var
    Ctotal, t2 : real;

  Begin       { TotalPollutantConc }
    If ((DegConstPol * t) > MaxExp) or (x < SlugTop) or (x > SlugBottom) then
      TotalPollutantConc := 0.0
    Else
      Begin
        Ctotal := InitialConcPol * exp(-t * DegConstPol);
        If x <= PlowZoneDepth then TotalPollutantConc := Ctotal
        Else
          Begin
            t2 := t - (x - PlowZoneDepth)/vp;
            If (DegConstOil * t2) > MaxExp then TotalPollutantConc := Ctotal
            Else TotalPollutantConc := Ctotal * r / (r + rt * exp(-DegConstOil*t2));
          End;
      End;
  End;        { TotalPollutantConc }




Function AqueousPollutantConc(x, t, TotalConc : real) : real;

                                  { Returns the concentration of the pollutant
                                    in the water at depth x, and time t when 
                                    the concentration of the pollutant in all
                                    phases at this time and depth is TotalConc.

                                    External constants used : 
                                      MaxExp = 350.
                                    External variables used:
                                      DegConstOil   
                                      r             
                                      rt            
                                      PlowZoneDepth 
                                      WaterContent  
                                    }


  Begin       { AqueousPollutantConc }
    If TotalConc = 0.0 then AqueousPollutantConc := 0.0
    Else
      If ((DegConstOil * t) > MaxExp) or (x > PlowZoneDepth) then
        AqueousPollutantConc := TotalConc/(r * WaterContent)
      Else AqueousPollutantConc := TotalConc / (WaterContent*(r + rt * exp(-DegConstOil * t)));
  End;        { AqueousPollutantConc }




Function SoilPollutantConc(AqueousConc : real) : real;

                                  { Returns the concentration of pollutant in
                                    solid phase when the concentration in
                                    water at the time and position of interest
                                    is AqueousConc.

                                    External constants used : none

                                    External variables used :
                                      kd
                                    }


  Begin       { SoilPollutantConc }
    SoilPollutantConc := AqueousConc * kd;
  End;        { SoilPollutantConc }




Function VaporPollutantConc(AqueousConc : real) : real;

                                  { Returns the concentration of the pollutant
                                    in the vapor phase when the concentration
                                    in water at the position and time of
                                    interest is AqueousConc.

                                    External constants used : none

                                    External variables used :
                                      kh 
                                    }


  Begin       { VaporPollutantConc }
    VaporPollutantConc := AqueousConc * kh;
  End;        { VaporPollutantConc }




Function OilPollutantConc(x, AqueousConc : real) : real;

                                  { Returns the concentration of the pollutant
                                    in the oil phase for depth x when the 
                                    concentration in water at depth x and the 
                                    time of interest is AqueousConc.

                                    External constants used : none

                                    External variables used :
                                      kow
                                      PlowZoneDepth  
                                    }


  Begin       { OilPollutantConc }
    If x <= PlowZoneDepth then OilPollutantConc := AqueousConc * kow
    Else OilPollutantConc := 0.0;
  End;        { OilPollutantConc }





Function OilContent(x, t:real):real;

                                  { Returns the volume of oil per unit volume 
                                    of soil at time t and depth x.

                                    External constants used : 
                                      MaxExp = 350.
                                    External variables used:
                                      DegConstOil    
                                      Initial OilContent
                                      PlowZoneDepth
                                    }


  Begin       { OilContent }
    If (x > PlowZoneDepth) or ((DegConstOil * t) > MaxExp) then OilContent := 0.0
    Else OilContent := InitialOilContent * exp(-t*DegConstOil);
  End;        { OilContent }





Function TimeOfTop(x : real):real;  

                                  { Returns time at which the top of the 
                                    pollutant slug reaches the depth x. 
                                    Return 0 if x < 0 or x > treatment zone
                                    depth.

                                    External constants used :
                                      MaxExp = 350.0

                                    External variables used :
                                      DegConstOil
                                      r          
                                      rt         
                                      vp         
                                      g          
                                      PlowZoneDepth 
                                      TreatZoneDepth
                                    }

  Var
    dummy1,dummy2,
    dummy3,dummy4   : real;

  Begin       { TimeOfTop }
    If (x <= 0.0) or (x > TreatZoneDepth) then TimeOfTop := 0.0
    Else If x <= PlowZoneDepth then
      Begin
        dummy1 := rt/r;
        dummy2 := 1.0 + dummy1;
        dummy3 := x * DegConstOil/ vp;
        dummy4 := ( a * DegConstOil / vp )*ln( 1.0 + x / g);
        If dummy3 <= MaxExp then
          TimeOfTop :=  ln( dummy2 * exp( dummy3 - dummy4) - dummy1 ) / DegConstOil
        Else
          TimeOfTop := (dummy3 - dummy4 + ln(dummy2)) / DegConstOil;
      End
    Else If x <= TreatZoneDepth then
      Begin
        TimeOfTop := TimeOfTop(PlowZoneDepth) + (( x - PlowZoneDepth) / vp )
                          - ( a / vp ) * ln( ( g + x ) / ( g + PlowZoneDepth ));
      End;
  End;        { TimeOfTop }




Procedure LocateTopBottom(t : real; var Top : real; var Bottom : real);

                                  { Calculate the depths of the top and
                                    bottom of the pollutant slug at time t.
                                    On exit from procedure, depths are stored
                                    in variables Top and Bottom, respectively.

                                    External constants used : None

                                    External variables used : 
                                      MaxDepthSlug  
                                      TimeToClearTZ          
                                      TimeToPZ          
                                      PlowZoneDepth 
                                      vp            
                                    }


  Var
    x1, x2, xm, tm : real;
    i : integer;

  Begin       { LocateTopBottom }
    If t = 0 then Top := 0
    Else
      If t >= TimeToClearTZ then Top := MaxDepthSlug
      Else
        If t < TimeToPZ then
          Begin
            x1 := 0;
            x2 := PlowZoneDepth;
            For i := 1 to 16 do
              Begin
                xm := (x1+x2)/2;
                tm := TimeOfTop(xm);
                If tm > t then x2 := xm
                Else x1 := xm;
              End;
            Top := xm;
          End
        Else
          Begin
            x1 := PlowZoneDepth;
            x2 := MaxDepthSlug;
            For i := 1 to 24 do
              Begin
                xm := (x1 + x2)/2;
                tm := TimeOfTop(xm);
                If tm > t then x2 := xm
                Else x1 := xm;
              End;
            Top := xm;
          End;
    Bottom := PlowZoneDepth + vp * t;
    If Bottom > MaxDepthSlug then Bottom := MaxDepthSlug;
  End;        { LocateTopBottom }





Function VaporFlux(time, depth : real) : real;

                                  { Returns flux of pollutant as vapor at 
                                    specified time. The location of the top of
                                    the pollutant slug at this time is stored
                                    in variable depth.

                                    External constants used : 
                                      MaxExp = 350.

                                    External variables used:
                                      InitialConcPol
                                      DegConstPol   
                                      DegConstOil   
                                      r             
                                      rt
                                      vp            
                                      a
                                      g
                                      PlowZoneDepth 
                                    }



  Var
    dTime  : real;

  Begin       { VaporFlux }
    If (DegConstPol * time) > MaxExp then VaporFlux := 0.0
    Else
      If depth<=PlowZoneDepth then
        Begin
          If (DegConstOil * time) > MaxExp then
            VaporFlux := InitialConcPol * exp(-DegConstPol*time) * a * vp /(g+depth-a)
          Else
            VaporFlux := InitialConcPol * exp(-DegConstPol*time) * a * vp/
                         ((g+depth-a)*(1.0+(rt/r)*exp(-DegConstOil*time)));
        End
      Else
        Begin
          dTime := time - (depth - PlowZoneDepth)/vp;
          If (DegConstOil * dTime) > MaxExp then
            VaporFlux := InitialConcPol * exp(-DegConstPol*time) * a * vp /(g+depth-a)
          Else
            VaporFlux := InitialConcPol * exp(-DegConstPol*time) * a * vp/
                         ((g+depth-a)*(1.0+(rt/r)*exp(-DegConstOil*dtime)));
        End;
  End;        { VaporFlux }





  Function LiquidFlux(t : real) : real;

                                  { Returns the flux of pollutant leached below
                                    the treatment zone depth at time t.

                                    External constants used : None

                                    External variables used :
                                      RechargeRate
                                      TreatZoneDepth
                                      TimeToTZ
                                      TimeToClearTZ
                                    }

    Var
      tzd : real;

    Begin      { LiquidFlux }
      tzd := TreatZoneDepth;
      If (t >= TimeToTZ) and (t <= TimeToClearTZ) then
        LiquidFlux := RechargeRate * AqueousPollutantConc(tzd, t,
                                      TotalPollutantConc(tzd, t, tzd, tzd))
      Else LiquidFlux := 0;
    End;       { LiquidFlux }





Procedure MassBalance(Precision : real;  { Desired computational precision }
                      var Error : real;  { Mass balance error }
                var Degradation : real;  { Mass degraded }
             var Volatilization : real;  { Mass volatilized }
                   var Leachate : real); { Mass leached }

                                  { Procedure calculates the mass of pollutant
                                    degraded, volatilized, and leached and the
                                    computational mass balance error.

                                    External constants used : None

                                    External variables used :
                                      PollutantLoad
                                      PlowZoneDepth
                                      TreatZoneDepth
                                      MaxDepthSlug
                                      TimeToPZ
                                      TimeToClearTZ
                                      TimeToTZ
                                    }



  Function Ac(t, xb, xt : real) : real;  

                                  { Returns the mass of the pollutant 
                                    accumulated below the plow zone at time t.
                                    The depths of the top and bottom of the
                                    pollutant slug at time t are xt and xb, respectively.

                                    External constants used : 
                                      MaxExp = 350.

                                    External variables used:
                                      InitialConcPol
                                      DegConstPol   
                                      DegConstOil   
                                      r
                                      rt
                                      vp            
                                      PlowZoneDepth
                                    }



    Var
      xbh, numerator, denominator, Z, Z1 : real;

    Begin         { ac }
      xbh := PlowZoneDepth + vp * t;
      If DegConstPol*t>MaxExp then ac := 0.0
      Else
        Begin
          Z := DegConstOil * (xbh - xb) / vp;
          If Z > MaxExp then numerator := 1.0
          else numerator := 1.0 + (rt/r) * exp(-Z);
          Z1 := DegConstOil * (xbh - xt)/vp;
          If Z1 > MaxExp then denominator := 1.0
          Else denominator := 1.0 + (rt/r) * exp(-Z1);
          ac := InitialConcPol * exp(-DegConstPol * t) * ((xb - xt) -
                                (vp/DegConstOil) * ln(numerator/denominator));
        End;
    End;          { ac }





  Function DegradIntPZ(x : real) : real;  

                                  { Returns the integrand for the degradation
                                    in the plow zone. The location of the top
                                    of the pollutant slug is given by x.
                                    (x is the variable of integration)

                                    External constants used : 
                                      MaxExp = 350.

                                    External variables used:
                                      DegConstPol 
                                      DegConstOil 
                                      r           
                                      rt          
                                      vp          
                                      a
                                      g
                                      PlowZoneDepth
                                    }


    Var
      time,
      dtdx,
      acct    : real;

    Begin         { DegradIntPZ }
      If x > PlowZoneDepth then DegradIntPZ := 0.0
      Else
        Begin
          time := TimeOfTop(x);
          dtdx := (g + x - a) / (vp * (g + x));
          If DegConstOil*time<=MaxExp then
            dtdx := dtdx * (1.0 + (rt / r ) * exp( -DegConstOil * time));
          DegradIntPZ := TotalPollutantConc(x,time,x,PlowZoneDepth)*DegConstPol*dtdx*(PlowZoneDepth-x);
        End;
    End;          { DegradIntPZ }





  Function DegradIntBoth(t:real):real;

                                  { Returns the integrand for degradation in
                                    the treatment zone for time t in which the
                                    top of the slug is in the plow zone. 

                                    External constants used : None

                                    External variables used:
                                      DegConstPol  
                                      vp
                                      PlowZoneDepth
                                      TreatZoneDepth
                                    }


    Var
      xb,
      acc   : real;

    Begin         { DegradIntBoth }
      If t > TimeToClearTZ then DegradIntBoth := 0.0
      Else
        Begin
          xb := PlowZoneDepth + vp * t;
          If ( xb > TreatZoneDepth ) then xb := TreatZoneDepth;
          acc := ac( t,xb,PlowZoneDepth );
          DegradIntBoth := DegConstPol * acc;
        End;
    End;          { DegradIntBoth }





  Function DegradIntTZ(x:real):real;  

                                  { Returns the integrand for degradation in the
                                    treatment zone for times in which the top
                                    of the slug is in the treatment zone. The
                                    top of the pollutant slug is at depth x.

                                    External constants used : 
                                      MaxExp = 350.

                                    External variables used:
                                      DegConstPol   
                                      vp
                                      a
                                      g
                                      PlowZoneDepth 
                                      TreatZoneDepth
                                      MaxDepthSlug  
                                    }


    Var
      xb,
      dtdx,
      acc,
      time  : real;

    Begin         { DegradIntTZ }
      If x > MaxDepthSlug then DegradIntTZ := 0.0
      Else
        Begin
          time := TimeOfTop(x);
          dtdx := ( g - a + x ) / ( vp * ( g + x ));
          xb := PlowZoneDepth + vp * time;
          If (xb >= TreatZoneDepth) then xb := TreatZoneDepth;
          acc := ac(time,xb,x);
          DegradIntTZ := DegConstPol * acc * dtdx;
        End;
    End;          { DegradIntTZ }





  Function VolatileIntPZ(x : real) : real;

                                  { Returns the integrand for the volatiliza-
                                    tion in the plow zone for top of pollutant
                                    slug at depth x.

                                    External constants used :
                                      MaxExp = 350.

                                    External variables used :
                                      DegConstPol
                                      a
                                      g
                                      PlowZoneDepth
                                    }

    Var
      time   : real;

    Begin         { VolatileIntPZ }
      If x > PlowZoneDepth then VolatileIntPZ := 0.0
      Else
        Begin
          time := TimeOfTop(x);
          If DegConstPol*time>MaxExp then VolatileIntPZ := 0.0
          Else
            VolatileIntPZ := a * InitialConcPol * exp( -DegConstPol * time ) / ( g + x );
        End;
    End;          { VolatileIntPZ }





  Function VolatileIntTZ(x : real) : real;   

                                  { Returns the integrand for the volatiliza-
                                    tion in the treatment zone where x is the
                                    depth of the top of the pollutant slug.

                                    External constants used :
                                      MaxExp = 350.

                                    External variables used :
                                      DegConstPol   
                                      DegConstOil   
                                      r
                                      rt            
                                      vp            
                                      a
                                      g
                                      PlowZoneDepth 
                                      MaxDepthSlug  
                                    }


    Var
      t, Z,
      dtdx,
      xb,
      flux  : real;

    Begin         { VolatileIntTZ }
      If x > MaxDepthSlug then VolatileIntTZ := 0.0
      Else
        Begin
          t := TimeOfTop(x);
          xb := PlowZoneDepth + vp * t;
          If DegConstPol*t>MaxExp then VolatileIntTZ := 0.0
          Else
            Begin
              Z := DegConstOil * (xb - x) / vp;
              If Z>MaxExp then
                VolatileIntTZ := InitialConcPol * exp( -DegConstPol * t ) * a / (g + x)
              Else
                VolatileIntTZ := InitialConcPol * exp(-DegConstPol * t) * a /
                                             ((g + x) * (1 + (rt/r) * exp(-Z)));
            End;
        End;
    End;          { VolatileIntTZ }





  Procedure Romberg ( lower, upper : real;  { Lower and Upper limits of integration }
                         precision : real;  { Absolute precision desired.           }
                          equation : char;  { Char specifying eqn to be integrated  }
                      var Integral : real;  { Value of Integral returned.           }
                         var error : real); { Absolute error in value returned.     }
                                            { Absolute error is the difference      }
                                            { between best two estimates.           }
                                            { Reference: Ralston, pp 121-129.       }

                                  { Calculates the integral of specified
                                    equation between lower and upper limits
                                    to specified precision if possible. Returns
                                    absolute error. This routine is used here 
                                    for calculating the amount of pollutant
                                    volatilized, degraded, and leached.

                                    External constants used :
                                      DEG_PZ  
                                      DEG_BOTH
                                      DEG_TZ 
                                      VOL_PZ 
                                      VOL_TZ
                                      LEACH

                                    External variables used : None
                                    }


    Var
      T : Array [0..20,0..20] of real;
      max, m, k, i : integer;
      four_to_m, sum, delta : real;

    Begin     { Romberg }
      Case Equation of
        DEG_PZ   : sum := (DegradIntPZ(lower)  + DegradIntPZ(upper))  / 2.0;
        DEG_BOTH : sum := (DegradIntBoth(lower) + DegradIntBoth(upper)) / 2.0;
        DEG_TZ   : sum := (DegradIntTZ(lower) + DegradIntTZ(upper)) / 2.0;
        VOL_PZ   : sum := (VolatileIntPZ(lower)  + VolatileIntPZ(upper))  / 2.0;
        VOL_TZ   : sum := (VolatileIntTZ(lower)  + VolatileIntTZ(upper))  / 2.0;
        LEACH    : sum := (LiquidFlux(lower) + LiquidFlux(upper)) / 2.0;
      End;
      T[0,0] := sum * (upper - lower);
      Four_to_m := 1.0;
      k := 1;
      max := 1;
      delta := upper - lower;
      Repeat
        i := 1;
        max := max * 2;
        delta := delta / 2.0;
        Repeat
          Case Equation of
            DEG_PZ   : sum := sum + DegradIntPZ(lower + i * delta);
            DEG_BOTH : sum := sum + DegradIntBoth(lower + i * delta);
            DEG_TZ   : sum := sum + DegradIntTZ(lower + i * delta);
            VOL_PZ   : sum := sum + VolatileIntPZ(lower + i * delta);
            VOL_TZ   : sum := sum + VolatileIntTZ(lower + i * delta);
            LEACH    : sum := sum + LiquidFlux(lower + i * delta);
          End;
          i := i + 2;
        Until (i > max);
        T[0,k] := delta * sum;
        m := k;
        Four_to_m := 1.0;
        For i := 1 to k do
          Begin
            Four_to_m := Four_to_m * 4.0;
            T[i,k-i] := (Four_to_m * T[i-1,k-i+1] - T[i-1,k-i])/ (Four_to_m - 1.0);
          End;
        k := k + 1;
        Error := ABS(T[m,0]-T[m-1,0]);
      Until (m > 4 ) and ((Error <= precision) or ( k > 20));
      Integral := T[m,0];
    End;          { Romberg }





  Var
    DegradPZ,
    DegradBoth,
    DegradTZ,
    VolPZ,
    VolTZ,
    x,
    dx : real;
    RelError : Boolean;

  Begin       { MassBalance }
    RelError := False;
    Romberg(0.0, PlowZoneDepth/10000.0, Precision/5.0, DEG_PZ, DegradPZ, Error);
    Romberg(PlowZoneDepth/10000.0, PlowZoneDepth/100, Precision, DEG_PZ, x, dx);
    DegradPZ := DegradPZ + x;
    Error := dx + Error;
    Romberg(PlowZoneDepth/100.0, PlowZoneDepth, Precision/5.0, DEG_PZ, x, dx);
    DegradPZ := DegradPZ + x;
    Error := dx + Error;
    Romberg(0.0, TimeToPZ, Precision/5.0, DEG_BOTH, DegradBoth, dx);
    Error := dx + Error;
    Romberg(PlowZoneDepth,
                    PlowZoneDepth+0.01*(TreatZoneDepth-PlowZoneDepth),
                                            Precision/5.0, DEG_TZ, DegradTZ, dx);
    Error := Error + dx;
    Romberg(PlowZoneDepth+0.01*(TreatZoneDepth-PlowZoneDepth),
                    PlowZoneDepth+0.1*(TreatZoneDepth-PlowZoneDepth),
                                            Precision/5.0, DEG_TZ, x, dx);
    DegradTZ := DegradTZ + x;
    Error := Error + dx;
    Romberg(PlowZoneDepth+0.1*(TreatZoneDepth-PlowZoneDepth),
                    PlowZoneDepth+0.5*(TreatZoneDepth-PlowZoneDepth),
                                            Precision/5.0, DEG_TZ, x, dx);
    DegradTZ := DegradTZ + x;
    Error := Error + dx;
    Romberg(PlowZoneDepth+0.5*(TreatZoneDepth-PlowZoneDepth),
                    PlowZoneDepth+1.0*(TreatZoneDepth-PlowZoneDepth),
                                            Precision/5.0, DEG_TZ, x, dx);
    DegradTZ := DegradTZ + x;
    Error := Error + dx;
    If Error > Precision then
      Begin
        Writeln('Error in integration of degradation is ',Error:8);
        RelError := True;
      End;
    Romberg(0.0, PlowZoneDepth/10000.0, Precision/5.0, VOL_PZ, VolPZ, Error);
    Romberg(PlowZoneDepth/10000.0, PlowZoneDepth/100, Precision, VOL_PZ, x, dx);
    VolPZ := VolPZ + x;
    Error := dx + Error;
    Romberg(PlowZoneDepth/100.0, PlowZoneDepth, Precision/5.0, VOL_PZ, x, dx);
    VolPZ := VolPZ + x;
    Error := dx + Error;
    Romberg(PlowZoneDepth, MaxDepthSlug, Precision/5.0, VOL_TZ, VolTZ, dx);
    Error := Error + dx;
    If Error > Precision then
      Begin
        Writeln('Error in integration of volatiliztion is ',Error:8);
        RelError := True;
      End;
    Error := 0.0;
    If TimeToClearTZ <= TimeToTZ then Leachate := 0.0
    Else Romberg(TimeToTZ, TimeToClearTZ, Precision, LEACH, Leachate, Error);
    If Error > Precision then
      Begin
        Writeln('Error in integration of leaching is ',Error:8);
        RelError := True;
      End;
    Degradation := DegradPZ + DegradBoth + DegradTZ;
    Volatilization := VolPZ + VolTZ;
    Error := PollutantLoad - Degradation - Volatilization - Leachate;
    If RelError then
      Begin
        Writeln;
        Writeln(' Press any key to continue, or Esc to terminate.');
        Readln;
      End;
  End;        { MassBalance }





Procedure CalculateParm;

                                  { Calculate the global parameters from input
                                    parameters.

                                    External constants used : None

                                    External variables used :
                                      Global variables listed above.
                                    }

  Var
    x, y : real;

  Begin     { CaclParm }
    DegConstOil := 0.693/HalfLifeOil;
    DegConstPol := 0.693/HalfLifePol;
    DensityRatio := (4.60843696 + (0.40710817 + (0.302943E-2 + 0.39405E-3
                      *temp)*temp)*temp)/0.1E7;
    Kd := foc * koc;
    StagnantLayerThickness := DiffCoefWater * DensityRatio * ( 1.0 - rh) / (2.0 * EvapRate );
    x := 1.0 / ( 2.0 * ClappHornberger + 3.0 );
    y := RechargeRate / SatConductivity;
    If y < 1.0 then WaterContent := SatWaterContent * power(y,x)
    Else WaterContent := SatWaterContent;
    AqueousVelocity := RechargeRate / WaterContent;
    InitialConcPol  := SludgeApplRate * ConcPol / ( PlowZoneDepth * 0.1E5 );
    InitialOilContent := SludgeApplRate * ConcOil / ( DensityOil * PlowZoneDepth * 0.1E8 );
    InitialAirContent := SatWaterContent - WaterContent - InitialOilContent;
    x := 10.0/3.0;
    y := InitialAirContent;
    DiffCoefSoil := VaporDiffCoefAir *  power(y,x) / ( SatWaterContent * SatWaterContent );
    PollutantLoad := InitialConcPol * PlowZoneDepth;
    r := (( InitialOilContent + InitialAirContent ) * kh + bd * Kd + WaterContent ) / WaterContent;
    rt := InitialOilContent * ( kow - kh ) / WaterContent;
    a := kh * DiffCoefSoil / ( AqueousVelocity * WaterContent );
    g := ( DiffCoefSoil * StagnantLayerThickness / VaporDiffCoefAir ) + a;
    vp := AqueousVelocity / r;
    TimeToPZ := TimeOfTop(PlowZoneDepth);
    TimeToTZ := ( TreatZoneDepth - PlowZoneDepth ) / vp;
    TimeToClearTZ := TimeOfTop(TreatZoneDepth);
    If TimeToClearTZ > TimeToTZ then MaxDepthSlug := TreatZoneDepth
    Else MaxDepthSlug := (g+PlowZoneDepth)*Exp((vp*TimeToPZ)/a) - g;
  End;      { CaclParm }

